@@ -3,12 +3,12 @@ import json
 import logging
 
 
-class myconfig:
+class mock_config:
     def __init__(self, attributes):
         for k, v in attributes.items():
             setattr(self, k, v)
 
-class mylogger :
+class mock_logger :
 
     def info(self,msg_str):
         logging.info(msg_str)
@@ -20,14 +20,14 @@ class mylogger :
         logging.error(msg_str)
 
 
-class myapi:
+class mock_api:
 
     def __init__(self):
         with open(os.path.join(os.getcwd(),'operator.json')) as json_file:
             config_data = json.load(json_file)['config']
         del config_data['$type']
-        self.config = myconfig(config_data)
-        self.logger = mylogger()
+        self.config = mock_config(config_data)
+        self.logger = mock_logger()
 
     class Message:
         def __init__(self, body=None, attributes=""):
@@ -42,9 +42,3 @@ class myapi:
 
     def add_generator(self,func):
         func()
-
-
-try:
-    api
-except NameError:
-    api = myapi()
